@@ -2,7 +2,7 @@ from itertools import product
 import numpy as np
 from multiprocessing import Pool 
 from scrapegoat.utils import automate
-from scrapegoat.getLinks.get_links import search_links
+from scrapegoat.utils import search_links
 import time
 import os
 
